Changes
=======

Unreleased
----------

Version 0.4.0
-------------

Released 2021-12-11

- Migrate the project to poetry. `#33 <https://github.com/dajiaji/python-cwt/pull/33>`__
- Add support for kid. `#32 <https://github.com/dajiaji/python-cwt/pull/32>`__

Version 0.3.3
-------------

Released 2021-11-24

- Refine README and docstring for Read the Docs. `#29 <https://github.com/dajiaji/python-cwt/pull/29>`__
- Refine example. `#28 <https://github.com/dajiaji/python-cwt/pull/28>`__

Version 0.3.2
-------------

Released 2021-11-23

- Fix .readthedocs not to use setup.py. `#27 <https://github.com/dajiaji/python-cwt/pull/27>`__

Version 0.3.1
-------------

Released 2021-11-23

- Introduce flit for publishing. `#25 <https://github.com/dajiaji/python-cwt/pull/25>`__

Version 0.3.0
-------------

Released 2021-11-23

- Add PasetoIssuer and PasetoVerifier. `#19 <https://github.com/dajiaji/python-cwt/pull/19>`__

Version 0.2.0
-------------

Released 2021-10-24

- Refine app.config name for PasetoLoginManager. `#16 <https://github.com/dajiaji/python-cwt/pull/16>`__
- Add tests for PasetoLoginManager. `#16 <https://github.com/dajiaji/python-cwt/pull/16>`__
- Rename package name from Flask PASETO Extended to flask-paseto-extended. `#15 <https://github.com/dajiaji/python-cwt/pull/15>`__
- Add tests for PasetoCookieSessionInterface. `#14 <https://github.com/dajiaji/python-cwt/pull/14>`__

Version 0.1.1
-------------

Released 2021-10-23

- Activate Read the Docs. `#12 <https://github.com/dajiaji/python-cwt/pull/12>`__

Version 0.1.0
-------------

Released 2021-10-23

- First public release. `#11 <https://github.com/dajiaji/python-cwt/pull/11>`__
